<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name/>
    <message>
        <source>Delete</source>
        <translation type="vanished">刪除</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">全屏</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">幻燈片放映</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">導出</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">複製</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">收藏</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">順時針旋轉</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">逆時針旋轉</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">設為壁紙</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">在檔案管理員中顯示</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="vanished">照片訊息</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="vanished">影片訊息</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="vanished">恢復</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>未命名相冊</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>新建相冊</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>您確定要刪除此相冊嗎？</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>最近刪除</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>已導入</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>最近刪除</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>您也可以拖拽照片到此</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>全部導入</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>導入到：</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>導入</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>系統盤</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>照片庫</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>磁盤文件被佔用，無法彈出</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相冊</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>正在加載，請稍候...</translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation>文件在刪除前會顯示剩餘天數，之後將永久刪除</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>相冊</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>替換</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>導出</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>圖片</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文檔</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下載</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>文件名：</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>保存到：</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>文件格式：</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>照片質量：</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>選擇其他目錄</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>文件名不能為空</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>已存在，您是否要替換？</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation>截圖錄屏</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>相機</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>畫板</translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation>(副本)</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1驅動器</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>空白%1光盤</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1已加密</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1卷</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>導出照片</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>正在刪除...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>正在恢復...</translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this photo from the album?</source>
        <translation type="vanished">您確定要從相冊中刪除此照片嗎？</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n photos from albums?</source>
        <translation type="vanished"><numerusform>您確定要從相冊中刪除這%n張照片嗎？</numerusform></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this video from the album?</source>
        <translation type="vanished">您確定要從相冊中刪除此影片嗎？</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n videos from albums?</source>
        <translation type="vanished"><numerusform>您確定要從相冊中刪除這%n個影片嗎？</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n items from albums?</source>
        <translation type="vanished"><numerusform>您確定要從相冊中刪除這%n個項目嗎？</numerusform></translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation>您確定要永久刪除此文件嗎？</translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation>刪除後不可恢復</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation>您確定要永久刪除這%1個文件嗎？</translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation>刪除後不可恢復</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation>您確定要從本地刪除此文件嗎？</translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation>您可以在“最近刪除”中進行恢復</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation>您確定要從本地刪除這%1個文件嗎？</translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation>您可以在“最近刪除”中進行恢復</translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>基本訊息</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>詳細訊息</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>圖片訊息</translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>已導入</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation>共1張照片</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>共1個影片</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation><numerusform>共%n張照片</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation><numerusform>共%n個影片</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation><numerusform>共%n項</numerusform></translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation>導入照片和影片</translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation>您也可以拖拽照片和影片到此</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>所有照片和影片</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>未發現照片或影片文件</translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>導出</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>設備</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>照片庫</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>相冊</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相冊</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation>相冊是一款可多種方式瀏覽、整理照片和影片的管理工具。</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>照片</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>幫助</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在檔案管理員中顯示</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>設為壁紙</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>重命名相冊</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>已成功刪除“%1”相冊</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>成功添加到“%1”</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>導入成功</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>導出失敗</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>導出失敗</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>導出成功</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>所有照片</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>時間線</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>相冊</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>退出全屏/幻燈片放映</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>顯示快捷鍵</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>全選</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>放大照片</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>縮小照片</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相冊</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>向上滾動一屏</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>向下滾動一屏</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>正在導入，請稍候...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>所有照片和影片</translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation>導入照片和影片</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>未發現照片或影片文件</translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation>導出照片</translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation>導入照片和影片</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation>照片/影片訊息</translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation>導入照片和影片</translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation>從文件夾導入</translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation>導入中斷</translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation>不支持此路徑，請嘗試其他路徑</translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation>路徑已存在</translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation>%1個文件恢復失敗，文件名過長</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>閃光燈</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>文件類型</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>照片尺寸</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>拍攝日期</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>曝光模式</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>曝光程序</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>曝光時間</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>光圈大小</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>焦距</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO感光度</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>最大光圈值</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>測光模式</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>白平衡</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>閃光燈補償</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>相機型號</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>鏡頭型號</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>顏色空間</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>標記</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation>無結果</translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>系統盤</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>選擇</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>取消選擇</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1年%2月%3日</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>導入於</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1年%2月%3日 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>導入於</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全選</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>取消全選</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>恢復</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>All</source>
        <translation>所有項目</translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>照片</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <source>No results</source>
        <translation>無結果</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>正在導入，請稍候...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation>已導入%1/%2項</translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation>已刪除%1/%2項</translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation>%1個項目導入成功，%2個項目導入失敗</translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation>已選擇1張照片</translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation>已選擇1個影片</translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation>照片/影片已存在</translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation><numerusform>已選擇%n張照片</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation><numerusform>已選擇%n個影片</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation><numerusform>已選擇%n項</numerusform></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation>%1個項目導入成功，%2個項目已存在

</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>無搜索結果</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>搜索結果</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation>共找到1張照片</translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation><numerusform>共找到%n個影片</numerusform></translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation>共找到1個影片</translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation><numerusform>共找到%n項</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation><numerusform>共找到%n張照片</numerusform></translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation>1張照片</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1個影片</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation><numerusform>%n張照片</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation><numerusform>%n個影片</numerusform></translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation>正在導入：%1</translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation>正在導出：%1</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>導出</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在檔案管理員中顯示</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>設為壁紙</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>照片訊息</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>添加到相冊</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>從相冊中移除</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>恢復</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相冊</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>影片訊息</translation>
    </message>
    <message>
        <source>days</source>
        <translation>天</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation>共1張照片</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>共1個影片</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation><numerusform>共%n張照片</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation><numerusform>共%n個影片</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation><numerusform>共%n項</numerusform></translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>基本訊息</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation>編碼訊息</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation>音頻流訊息</translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation>影片流訊息</translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation>影片碼率</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>影片幀率</translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation>顯示比例</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>解像度</translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation>編碼樣式</translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation>編碼碼率</translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation>音頻位數</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>聲道數</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>聲道</translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation>採樣數</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>文件類型</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>時長</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>文件路徑</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>影片訊息</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>拍攝日期</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
</context>
</TS>